@@ -279,7 +279,8 @@ class GridFrame(wx.Frame):  # class GridFrame(wx.ScrolledWindow):
         self.main_sizer.Add(self.code_msg_boxsizer, 0,
                             flag=wx.BOTTOM|wx.ALIGN_CENTRE,#|wx.SHAPED,
                             border=5)
-        self.main_sizer.Add(self.grid_box, 2, flag=wx.ALL|wx.ALIGN_CENTER|wx.EXPAND, border=10)
+        #self.main_sizer.Add(self.grid_box, 2, flag=wx.ALL|wx.ALIGN_CENTER|wx.EXPAND, border=10) # DEBUG
+        self.main_sizer.Add(self.grid_box, 2, flag=wx.ALL)
         self.panel.SetSizer(self.main_sizer)
         panel_sizer = wx.BoxSizer(wx.VERTICAL)
         panel_sizer.Add(self.panel, 1, wx.EXPAND)
@@ -323,6 +324,11 @@ class GridFrame(wx.Frame):  # class GridFrame(wx.ScrolledWindow):
             if larger_width > actual_size[0] or larger_height > actual_size[1]:
                 self.SetSize((larger_width, larger_height))
         self.Centre()
+        # this forces a resize which works
+        s = self.GetSize()
+        self.SetSize((0,0))
+        self.SetSize(s)
+
 
     def toggle_help(self, event, mode=None):
         """
